==> snipe-it-6.3.0.zip: snipe-it-6.3.0/resources/lang/mk-MK/mail.php <==
<?php

return [
    'acceptance_asset_accepted' => 'A user has accepted an item',
    'acceptance_asset_declined' => 'A user has declined an item',
    'a_user_canceled' => 'Корисникот го откажал барањето за средство на веб-страницата',
    'a_user_requested' => 'Корисникот побарал средство на веб-страницата',
    'accessory_name' => 'Име на додаток:',
    'additional_notes' => 'Дополнителни забелешки:',
    'admin_has_created' => 'Администраторот создаде сметка за вас на :web веб-страница.',
    'asset' => 'Основно средство:',
    'asset_name' => 'Име на основното средство:',
    'asset_requested' => 'Бараното основно средство',
    'asset_tag' => 'Код на основното средство',
    'assigned_to' => 'Задолжен на',
    'best_regards' => 'Со почит,',
    'canceled' => 'Откажано:',
    'checkin_date' => 'Датум на раздолжување:',
    'checkout_date' => 'Датум на задолжување:',
    'click_to_confirm' => 'Ве молиме кликнете на следната врска за да ја потврдите вашата :web сметка:',
    'click_on_the_link_accessory' => 'Ве молиме кликнете на врската на дното за да потврдите дека сте го примиле додатокот.',
    'click_on_the_link_asset' => 'Ве молиме кликнете на врската на дното за да потврдите дека сте го примиле основното средство.',
    'Confirm_Asset_Checkin' => 'Asset checkin confirmation',
    'Confirm_Accessory_Checkin' => 'Accessory checkin confirmation',
    'Confirm_accessory_delivery' => 'Accessory delivery confirmation',
    'Confirm_license_delivery' => 'License delivery confirmation',
    'Confirm_asset_delivery' => 'Asset delivery confirmation',
    'Confirm_consumable_delivery' => 'Consumable delivery confirmation',
    'current_QTY' => 'Тековна количина',
    'Days' => 'Денови',
    'days' => 'Денови',
    'expecting_checkin_date' => 'Очекуван датум на раздолжување:',
    'expires' => 'Истекува',
    'Expiring_Assets_Report' => 'Извештај за истекување на средства.',
    'Expiring_Licenses_Report' => 'Извештај за истекување на лиценци.',
    'hello' => 'Здраво',
    'hi' => 'Здраво',
    'i_have_read' => 'Ги прочитав и се согласив со условите за користење и го примив ова средство.',
    'item' => 'Средство:',
    'Item_Request_Canceled' => 'Барањето е откажано',
    'Item_Requested' => 'Побарана ставка',
    'link_to_update_password' => 'Ве молиме кликнете на следната врска за да ја обновите вашата :web лозинка:',
    'login_first_admin' => 'Влезете во новата инсталација на Snipe-IT користејќи ги ингеренциите подолу:',
    'login' => 'Најава:',
    'Low_Inventory_Report' => 'Извештај за низок инвентар',
    'inventory_report' => 'Inventory Report',
    'min_QTY' => 'Минимална количина',
    'name' => 'Име',
    'new_item_checked' => 'Ново основно средство е задолжено на Ваше име, деталите се подолу.',
    'password' => 'Лозинка:',
    'password_reset' => 'Ресетирање на лозинка',

    'read_the_terms' => 'Ве молиме прочитајте ги условите за употреба подолу.',
    'read_the_terms_and_click' => 'Прочитајте ги условите за употреба подолу и кликнете на врската на дното за да потврдите дека ги прочитавте и се согласувате со условите за користење и сте ги добиле основните средства.',
    'requested' => 'Побарано:',
    'reset_link' => 'Вашата врска за ресетирање на лозинка',
    'reset_password' => 'За да ја ресетирате Вашата лозинка, притиснете на врската:',
    'serial' => 'Сериски',
    'supplier' => 'Добавувач',
    'tag' => 'Таг',
    'test_email' => 'Тест е-пошта од Snipe-IT',
    'test_mail_text' => 'Ова е тест од Snipe-IT Системот за управување со основни средства. Ако го добивте ова, е-поштата работи :)',
    'the_following_item' => 'Следната ставка е раздолжена: ',
    'low_inventory_alert' => 'There is :count item that is below minimum inventory or will soon be low.|There are :count items that are below minimum inventory or will soon be low.',
    'assets_warrantee_alert' => 'There is :count asset with a warranty expiring in the next :threshold days.|There are :count assets with warranties expiring in the next :threshold days.',
    'license_expiring_alert' => 'There is :count license expiring in the next :threshold days.|There are :count licenses expiring in the next :threshold days.',
    'to_reset' => 'За да ја ресетирате вашата :web лозинка, пополнете го овој формулар:',
    'type' => 'Тип',
    'upcoming-audits' => 'There is :count asset that is coming up for audit within :threshold days.|There are :count assets that are coming up for audit within :threshold days.',
    'user' => 'Корисник',
    'username' => 'Корисничко име',
    'welcome' => 'Добредојдовте :name',
    'welcome_to' => 'Добредојдовте на :web!',
    'your_credentials' => 'Вашите корисничко име и лозинка',
    'Accessory_Checkin_Notification' => 'Accessory checked in',
    'Asset_Checkin_Notification' => 'Asset checked in',
    'Asset_Checkout_Notification' => 'Asset checked out',
    'License_Checkin_Notification' => 'License checked in',
    'Expected_Checkin_Report' => 'Expected asset checkin report',
    'Expected_Checkin_Notification' => 'Reminder: :name checkin deadline approaching',
    'Expected_Checkin_Date' => 'An asset checked out to you is due to be checked back in on :date',
    'your_assets' => 'View Your Assets',
    'rights_reserved' => 'All rights reserved.',
];

==> snipe-it-7.0.11.zip: snipe-it-7.0.11/resources/lang/mk-MK/mail.php <==
<?php

return [

    'Accessory_Checkin_Notification' => 'Accessory checked in',
    'Accessory_Checkout_Notification' => 'Accessory checked out',
    'Asset_Checkin_Notification' => 'Asset checked in',
    'Asset_Checkout_Notification' => 'Asset checked out',
    'Confirm_Accessory_Checkin' => 'Accessory checkin confirmation',
    'Confirm_Asset_Checkin' => 'Asset checkin confirmation',
    'Confirm_accessory_delivery' => 'Accessory delivery confirmation',
    'Confirm_asset_delivery' => 'Asset delivery confirmation',
    'Confirm_consumable_delivery' => 'Consumable delivery confirmation',
    'Confirm_license_delivery' => 'License delivery confirmation',
    'Consumable_checkout_notification' => 'Consumable checked out',
    'Days' => 'Денови',
    'Expected_Checkin_Date' => 'An asset checked out to you is due to be checked back in on :date',
    'Expected_Checkin_Notification' => 'Reminder: :name checkin deadline approaching',
    'Expected_Checkin_Report' => 'Expected asset checkin report',
    'Expiring_Assets_Report' => 'Извештај за истекување на средства.',
    'Expiring_Licenses_Report' => 'Извештај за истекување на лиценци.',
    'Item_Request_Canceled' => 'Барањето е откажано',
    'Item_Requested' => 'Побарана ставка',
    'License_Checkin_Notification' => 'License checked in',
    'License_Checkout_Notification' => 'License checked out',
    'Low_Inventory_Report' => 'Извештај за низок инвентар',
    'a_user_canceled' => 'Корисникот го откажал барањето за средство на веб-страницата',
    'a_user_requested' => 'Корисникот побарал средство на веб-страницата',
    'acceptance_asset_accepted' => 'A user has accepted an item',
    'acceptance_asset_declined' => 'A user has declined an item',
    'accessory_name' => 'Име на додаток:',
    'additional_notes' => 'Дополнителни забелешки:',
    'admin_has_created' => 'Администраторот создаде сметка за вас на :web веб-страница.',
    'asset' => 'Основно средство:',
    'asset_name' => 'Име на основното средство:',
    'asset_requested' => 'Бараното основно средство',
    'asset_tag' => 'Код на основното средство',
    'assets_warrantee_alert' => 'There is :count asset with a warranty expiring in the next :threshold days.|There are :count assets with warranties expiring in the next :threshold days.',
    'assigned_to' => 'Задолжен на',
    'best_regards' => 'Со почит,',
    'canceled' => 'Откажано:',
    'checkin_date' => 'Датум на раздолжување:',
    'checkout_date' => 'Датум на задолжување:',
    'checkedout_from' => 'Checked out from',
    'checkedin_from'  => 'Checked in from',
    'checked_into' => 'Checked into',
    'click_on_the_link_accessory' => 'Ве молиме кликнете на врската на дното за да потврдите дека сте го примиле додатокот.',
    'click_on_the_link_asset' => 'Ве молиме кликнете на врската на дното за да потврдите дека сте го примиле основното средство.',
    'click_to_confirm' => 'Ве молиме кликнете на следната врска за да ја потврдите вашата :web сметка:',
    'current_QTY' => 'Тековна количина',
    'days' => 'Денови',
    'expecting_checkin_date' => 'Очекуван датум на раздолжување:',
    'expires' => 'Истекува',
    'hello' => 'Здраво',
    'hi' => 'Здраво',
    'i_have_read' => 'Ги прочитав и се согласив со условите за користење и го примив ова средство.',
    'inventory_report' => 'Inventory Report',
    'item' => 'Средство:',
    'item_checked_reminder' => 'This is a reminder that you currently have :count items checked out to you that you have not accepted or declined. Please click the link below to confirm your decision.',
    'license_expiring_alert' => 'There is :count license expiring in the next :threshold days.|There are :count licenses expiring in the next :threshold days.',
    'link_to_update_password' => 'Ве молиме кликнете на следната врска за да ја обновите вашата :web лозинка:',
    'login' => 'Најава:',
    'login_first_admin' => 'Влезете во новата инсталација на Snipe-IT користејќи ги ингеренциите подолу:',
    'low_inventory_alert' => 'There is :count item that is below minimum inventory or will soon be low.|There are :count items that are below minimum inventory or will soon be low.',
    'min_QTY' => 'Минимална количина',
    'name' => 'Име',
    'new_item_checked' => 'Ново основно средство е задолжено на Ваше име, деталите се подолу.',
    'notes' => 'Забелешки',
    'password' => 'Лозинка:',
    'password_reset' => 'Ресетирање на лозинка',
    'read_the_terms' => 'Ве молиме прочитајте ги условите за употреба подолу.',
    'read_the_terms_and_click' => 'Please read the terms of use below, and click on the link at the bottom to confirm that you read and agree to the terms of use, and have received the asset.',
    'requested' => 'Побарано:',
    'reset_link' => 'Вашата врска за ресетирање на лозинка',
    'reset_password' => 'За да ја ресетирате Вашата лозинка, притиснете на врската:',
    'rights_reserved' => 'All rights reserved.',
    'serial' => 'Сериски',
    'snipe_webhook_test' => 'Snipe-IT Integration Test',
    'snipe_webhook_summary' => 'Snipe-IT Integration Test Summary',
    'supplier' => 'Добавувач',
    'tag' => 'Таг',
    'test_email' => 'Тест е-пошта од Snipe-IT',
    'test_mail_text' => 'Ова е тест од Snipe-IT Системот за управување со основни средства. Ако го добивте ова, е-поштата работи :)',
    'the_following_item' => 'Следната ставка е раздолжена: ',
    'to_reset' => 'За да ја ресетирате вашата :web лозинка, пополнете го овој формулар:',
    'type' => 'Тип',
    'upcoming-audits' => 'There is :count asset that is coming up for audit within :threshold days.|There are :count assets that are coming up for audit within :threshold days.',
    'user' => 'Корисник',
    'username' => 'Корисничко име',
    'unaccepted_asset_reminder' => 'You have Unaccepted Assets.',
    'welcome' => 'Добредојдовте :name',
    'welcome_to' => 'Добредојдовте на :web!',
    'your_assets' => 'View Your Assets',
    'your_credentials' => 'Вашите корисничко име и лозинка',
    'mail_sent' => 'Mail sent successfully!',
];
